#!/usr/bin/env python3

from setuptools import setup

setup(
    name='lilist',
    version='0.1.0',
    description='A linear interpolation list class',
    url='http://github.com/MatthewScholefield/lilist',
    author='Matthew Scholefield',
    author_email='matthew331199@gmail.com',
    license='MIT',
    py_modules=[
        'lilist'
    ]
)
